summaryrefslogtreecommitdiff
path: root/gtk2_ardour/editor_drag.h
diff options
context:
space:
mode:
authorCarl Hetherington <carl@carlh.net>2012-03-22 16:41:23 +0000
committerCarl Hetherington <carl@carlh.net>2012-03-22 16:41:23 +0000
commit3120bae8b41f3eecad25534ab6953e1b123ab9de (patch)
tree83542178768a7ca38427e2751a5a933102957537 /gtk2_ardour/editor_drag.h
parentf9de5f6436486bd7fea3d7dfacc43c04af7dc85f (diff)
Don't leave internal edit mode when clicking on an automation region view (#4747).
git-svn-id: svn://localhost/ardour2/branches/3.0@11749 d708f5d6-7413-0410-9779-e7cbd77b26cf
Diffstat (limited to 'gtk2_ardour/editor_drag.h')
-rw-r--r--gtk2_ardour/editor_drag.h14
1 files changed, 11 insertions, 3 deletions
diff --git a/gtk2_ardour/editor_drag.h b/gtk2_ardour/editor_drag.h
index f39f5cfcb3..2c806126bd 100644
--- a/gtk2_ardour/editor_drag.h
+++ b/gtk2_ardour/editor_drag.h
@@ -932,11 +932,14 @@ private:
bool _zoom_out;
};
/** Drag of a range of automation data, changing value but not position */
class AutomationRangeDrag : public Drag
{
public:
- AutomationRangeDrag (Editor *, ArdourCanvas::Item *, std::list<ARDOUR::AudioRange> const &);
+ AutomationRangeDrag (Editor *, AutomationTimeAxisView *, std::list<ARDOUR::AudioRange> const &);
+ AutomationRangeDrag (Editor *, AudioRegionView *, std::list<ARDOUR::AudioRange> const &);
void start_grab (GdkEvent *, Gdk::Cursor* c = 0);
void motion (GdkEvent *, bool);
@@ -947,9 +950,14 @@ public:
return false;
}
+ bool active (Editing::MouseMode) {
+ return true;
+ }
+
private:
+ void setup (std::list<boost::shared_ptr<AutomationLine> > const &);
+
std::list<ARDOUR::AudioRange> _ranges;
- AutomationTimeAxisView* _atav;
/** A line that is part of the drag */
struct Line {
@@ -932,11 +932,14 @@ private:
bool _zoom_out;
};
-/** Drag of a range of automation data, changing value but not position */
+/** Drag of a range of automation data (either on an automation track or region gain),
+ * changing value but not position.
+ */
class AutomationRangeDrag : public Drag
{